@@ -2,7 +2,6 @@
 import copy
 import functools
 import glob
-import io
 import logging
 import re
 from typing import Any
@@ -18,13 +17,13 @@ from typing import Set
 from typing import Tuple
 from typing import Union
 
-from certbot_nginx._internal import nginxparser
-from certbot_nginx._internal import obj
-from certbot_nginx._internal.nginxparser import UnspacedList
 import pyparsing
 
 from certbot import errors
 from certbot.compat import os
+from certbot_nginx._internal import nginxparser
+from certbot_nginx._internal import obj
+from certbot_nginx._internal.nginxparser import UnspacedList
 
 logger = logging.getLogger(__name__)
 
@@ -211,11 +210,11 @@ class NginxParser:
             if item in self.parsed and not override:
                 continue
             try:
-                with io.open(item, "r", encoding="utf-8") as _file:
+                with open(item, "r", encoding="utf-8") as _file:
                     parsed = nginxparser.load(_file)
                     self.parsed[item] = parsed
                     trees.append(parsed)
-            except IOError:
+            except OSError:
                 logger.warning("Could not open file: %s", item)
             except UnicodeDecodeError:
                 logger.warning("Could not read file: %s due to invalid "
@@ -223,12 +222,6 @@ class NginxParser:
                                "supported.", item)
             except pyparsing.ParseException as err:
                 logger.warning("Could not parse file: %s due to %s", item, err)
-            except nginxparser.UnsupportedDirectiveException as e:
-                logger.warning(
-                    "%s:%d contained the '%s' directive, which is not supported by Certbot. The "
-                    "file has been ignored, which may prevent Certbot from functioning properly. "
-                    "Consider using the --webroot plugin and manually installing the certificate.",
-                    item, e.line_no, e.directive_name)
         return trees
 
     def _find_config_root(self) -> str:
@@ -261,10 +254,10 @@ class NginxParser:
                     continue
                 out = nginxparser.dumps(tree)
                 logger.debug('Writing nginx conf tree to %s:\n%s', filename, out)
-                with io.open(filename, 'w', encoding='utf-8') as _file:
+                with open(filename, 'w', encoding='utf-8') as _file:
                     _file.write(out)
 
-            except IOError:
+            except OSError:
                 logger.error("Could not open file for writing: %s", filename)
 
     def parse_server(self, server: UnspacedList) -> Dict[str, Any]:
@@ -437,9 +430,9 @@ class NginxParser:
 def _parse_ssl_options(ssl_options: Optional[str]) -> List[UnspacedList]:
     if ssl_options is not None:
         try:
-            with io.open(ssl_options, "r", encoding="utf-8") as _file:
+            with open(ssl_options, "r", encoding="utf-8") as _file:
                 return nginxparser.load(_file)
-        except IOError:
+        except OSError:
             logger.warning("Missing NGINX TLS options file: %s", ssl_options)
         except UnicodeDecodeError:
             logger.warning("Could not read file: %s due to invalid character. "
