@@ -1,11 +1,12 @@
 """Test for certbot_nginx._internal.configurator."""
 import sys
-import unittest
 from unittest import mock
 
-import OpenSSL
 import pytest
 
+from cryptography import x509
+from cryptography.hazmat.primitives import serialization
+
 from acme import challenges
 from acme import messages
 from certbot import achallenges
@@ -546,12 +547,10 @@ class NginxConfiguratorTest(util.NginxTest):
         cert, key = self.config._get_snakeoil_paths()
         assert os.path.exists(cert)
         assert os.path.exists(key)
-        with open(cert) as cert_file:
-            OpenSSL.crypto.load_certificate(
-                OpenSSL.crypto.FILETYPE_PEM, cert_file.read())
-        with open(key) as key_file:
-            OpenSSL.crypto.load_privatekey(
-                OpenSSL.crypto.FILETYPE_PEM, key_file.read())
+        with open(cert, "rb") as cert_file:
+            x509.load_pem_x509_certificate(cert_file.read())
+        with open(key, "rb") as key_file:
+            serialization.load_pem_private_key(key_file.read(), password=None)
 
     def test_redirect_enhance(self):
         # Test that we successfully add a redirect when there is
@@ -1075,22 +1074,18 @@ class InstallSslOptionsConfTest(util.NginxTest):
         file has been manually edited by the user, and will refuse to update it.
         This test ensures that all necessary hashes are present.
         """
-        import pkg_resources
+        import importlib.resources
 
         from certbot_nginx._internal.constants import ALL_SSL_OPTIONS_HASHES
-        all_files = [
-            pkg_resources.resource_filename("certbot_nginx",
-                os.path.join("_internal", "tls_configs", x))
-            for x in ("options-ssl-nginx.conf",
-                      "options-ssl-nginx-old.conf",
-                      "options-ssl-nginx-tls12-only.conf")
-        ]
-        assert all_files
-        for one_file in all_files:
-            file_hash = crypto_util.sha256sum(one_file)
-            assert file_hash in ALL_SSL_OPTIONS_HASHES, \
-                f"Constants.ALL_SSL_OPTIONS_HASHES must be appended with the sha256 " \
-                f"hash of {one_file} when it is updated."
+
+        tls_configs_ref = importlib.resources.files("certbot_nginx").joinpath(
+            "_internal", "tls_configs")
+        with importlib.resources.as_file(tls_configs_ref) as tls_configs_dir:
+            for tls_config_file in os.listdir(tls_configs_dir):
+                file_hash = crypto_util.sha256sum(os.path.join(tls_configs_dir, tls_config_file))
+                assert file_hash in ALL_SSL_OPTIONS_HASHES, \
+                    f"Constants.ALL_SSL_OPTIONS_HASHES must be appended with the sha256 " \
+                    f"hash of {tls_config_file} when it is updated."
 
     def test_nginx_version_uses_correct_config(self):
         self.config.version = (1, 5, 8)
